pub struct EnabledCacheConfig {
pub ttl: Option<Duration>,
pub stale: Option<Duration>,
pub policy: CacheBehaviorPolicy,
pub concurrency: Option<ConcurrencyLimit>,
}Expand description
Enabled cache configuration with TTL, staleness, and behavior settings.
Fields
ttl: Option<Duration>Time-to-live before cache entry expires and becomes invalid (e.g., “5s”, “500ms”, “1m”).
stale: Option<Duration>Time from cache write until the entry becomes stale (e.g., “5s”, “500ms”, “1m”).
policy: CacheBehaviorPolicyCache behavior policy.
concurrency: Option<ConcurrencyLimit>Concurrency limit for dogpile prevention.